@@ -52,10 +52,12 @@ def updateDatabaseIfNeeded(context):
     # Check for required IIntIds utility
     intids = queryUtility(IIntIds)
     if intids is None:
-        intids = IntIds()
-        locate(intids, default)
-        IComponentRegistry(sm).registerUtility(intids, IIntIds)
-        default['IntIds'] = intids
+        intids = default.get('IntIds')
+        if intids is None:
+            intids = IntIds()
+            locate(intids, default)
+            default['IntIds'] = intids
+            IComponentRegistry(sm).registerUtility(intids, IIntIds)
     # Check for required catalog and index
     catalog = default.get('Catalog')
     if catalog is None:
